@@ -18,17 +18,19 @@
 #define __UNIX__ 1
 
 #include <stdio.h>
-#include <ctype.h>
-#include <fcntl.h>
-#include <limits.h>
-#include <math.h>
 #include <pwd.h>
+#include <assert.h>
+#include <errno.h>
+#include <fcntl.h>
+#include <ctype.h>
+#include <math.h>
+#include <string.h>
+#include <limits.h>
 #ifdef NO_STDLIB_H
 #   include "../compat/stdlib.h"
 #else
 #   include <stdlib.h>
 #endif
-#include <string.h>
 #include <sys/types.h>
 #include <sys/file.h>
 #ifdef HAVE_SYS_SELECT_H
@@ -43,9 +45,9 @@
 #   include <time.h>
 #else
 #   if HAVE_SYS_TIME_H
-#       include <sys/time.h>
+#	include <sys/time.h>
 #   else
-#       include <time.h>
+#	include <time.h>
 #   endif
 #endif
 #if HAVE_INTTYPES_H
@@ -189,4 +191,10 @@
 	sprintf((buf), "%#08lx", (unsigned long) (w))
 #endif
 
+/*
+ * Used by tkWindow.c
+ */
+
+#define TkpHandleMapOrUnmap(tkwin, event)  Tk_HandleEvent(event)
+
 #endif /* _UNIXPORT */
